API
===

Core
----

.. automodule:: pydiverse.transform
    :members:
    :undoc-members:

    .. autodata:: pydiverse.transform.λ


Builtin Verbs
-------------

.. automodule:: pydiverse.transform.core.verbs
    :members:
    :undoc-members:


Operators
---------

.. automodule:: pydiverse.transform.core.ops.aggregate
    :members:
.. automodule:: pydiverse.transform.core.ops.logical
    :members:
.. automodule:: pydiverse.transform.core.ops.numeric
    :members:
.. automodule:: pydiverse.transform.core.ops.string
    :members:
.. automodule:: pydiverse.transform.core.ops.window
    :members:


Functions
---------

.. automodule:: pydiverse.transform.core.functions
    :members:
    :undoc-members:


Table Implementations
---------------------

.. autoclass:: pydiverse.transform.eager.PandasTableImpl
.. autoclass:: pydiverse.transform.lazy.SQLTableImpl
